@@ -1,4 +1,5 @@
 # utils -----
+#' @importFrom officer fp_tab fp_tabs
 ooxml_ppr <- function(paragraphs_properties, type = "wml") {
   data_ref_pars <- distinct_paragraphs_properties(paragraphs_properties)
 
@@ -28,6 +29,16 @@ ooxml_ppr <- function(paragraphs_properties, type = "wml") {
       width = zz$border.width.left,
       style = zz$border.style.left
     )
+    if (!is.na(zz$tabs)) {
+      fp_tabs_ <- strsplit(zz$tabs, "&")[[1]]
+      fp_tabs_ <- lapply(strsplit(fp_tabs_, "_"), function(x) {
+        fp_tab(pos = as.numeric(x[2]), style = x[1])
+      })
+      zz$tabs <- do.call(fp_tabs, fp_tabs_)
+    } else {
+      zz$tabs <- NULL
+    }
+
 
     # delete names not in formals
     zz[grepl(pattern = "^(border\\.color|border\\.width|border\\.style)", names(zz))] <- NULL
@@ -50,8 +61,8 @@ ooxml_ppr <- function(paragraphs_properties, type = "wml") {
   paragraphs_properties <- merge(paragraphs_properties, style_dat, by = "classname")
   paragraphs_properties <- paragraphs_properties[, .SD,
     .SDcols = c(
-      ".part", "ft_row_id",
-      "col_id", "fp_par_xml"
+      ".part", ".row_id",
+      ".col_id", "fp_par_xml"
     )
   ]
   setDF(paragraphs_properties)
@@ -102,11 +113,11 @@ copy_border_bottom_to_next_border_top <- function(x, value) {
   }
 
   x[
-    !(x$.part %in% first_partname & x$ft_row_id %in% 1),
+    !(x$.part %in% first_partname & x$.row_id %in% 1),
     c("border.width.top", "border.color.top", "border.style.top")
   ] <-
     x[
-      !(x$.part %in% last_partname & x$ft_row_id %in% max_n),
+      !(x$.part %in% last_partname & x$.row_id %in% max_n),
       c("border.width.bottom", "border.color.bottom", "border.style.bottom")
     ]
   x
@@ -118,11 +129,11 @@ wml_cells <- function(value, cell_data) {
 
   cell_data$width <- NULL # need to get rid of originals that are empty, should probably rm them
   cell_data$height <- NULL
-  cell_data <- merge(cell_data, cell_widths, by = "col_id")
-  cell_data <- merge(cell_data, cell_heights, by = c(".part", "ft_row_id"))
+  cell_data <- merge(cell_data, cell_widths, by = ".col_id")
+  cell_data <- merge(cell_data, cell_heights, by = c(".part", ".row_id"))
 
   setDT(cell_data)
-  setorderv(cell_data, cols = c(".part", "ft_row_id", "col_id"))
+  setorderv(cell_data, cols = c(".part", ".row_id", ".col_id"))
 
   # fix for word horiz. borders, copying the bottom props to top props of the next cell
   cell_data <- copy_border_bottom_to_next_border_top(cell_data, value = value)
@@ -184,8 +195,8 @@ wml_cells <- function(value, cell_data) {
   cell_data <- merge(cell_data, style_dat, by = "classname")
   cell_data <- cell_data[, .SD,
     .SDcols = c(
-      ".part", "ft_row_id",
-      "col_id", "fp_cell_wml"
+      ".part", ".row_id",
+      ".col_id", "fp_cell_wml"
     )
   ]
   setDF(cell_data)
@@ -196,14 +207,14 @@ wml_cells <- function(value, cell_data) {
 
 wml_rows <- function(value, split = FALSE) {
   # prepare cells formatting properties and add span information
-  cell_attributes <- fortify_cells_properties(value)
+  cell_attributes <- information_data_cell(value)
   span_data <- fortify_span(value)
   setDT(cell_attributes)
-  cell_attributes <- merge(cell_attributes, span_data, by = c(".part", "ft_row_id", "col_id"))
+  cell_attributes <- merge(cell_attributes, span_data, by = c(".part", ".row_id", ".col_id"))
   setDF(cell_attributes)
 
   # prepare paragraphs formatting properties
-  paragraphs_properties <- fortify_paragraphs_properties(value)
+  paragraphs_properties <- information_data_paragraph(value)
 
   # transform alignments for rotated text
   # and add them back to paragraphs_properties and cell_attributes
@@ -216,17 +227,17 @@ wml_rows <- function(value, split = FALSE) {
   cell_attributes$vertical.align <- new_pos$valign
 
   # get runs in wml format and get hyperlinks and images information
-  run_data <- runs_as_wml(value, txt_data = fortify_run(value))
+  run_data <- runs_as_wml(value, txt_data = information_data_chunk(value))
 
   cell_data <- wml_cells(value, cell_attributes)
   cell_heights <- fortify_height(value)
   cell_hrule <- fortify_hrule(value)
 
   setDT(cell_data)
-  tab_data <- merge(cell_data, ooxml_ppr(paragraphs_properties), by = c(".part", "ft_row_id", "col_id"))
-  tab_data <- merge(tab_data, run_data, by = c(".part", "ft_row_id", "col_id"))
-  tab_data <- merge(tab_data, span_data, by = c(".part", "ft_row_id", "col_id"))
-  setorderv(tab_data, cols = c(".part", "ft_row_id", "col_id"))
+  tab_data <- merge(cell_data, ooxml_ppr(paragraphs_properties), by = c(".part", ".row_id", ".col_id"))
+  tab_data <- merge(tab_data, run_data, by = c(".part", ".row_id", ".col_id"))
+  tab_data <- merge(tab_data, span_data, by = c(".part", ".row_id", ".col_id"))
+  setorderv(tab_data, cols = c(".part", ".row_id", ".col_id"))
 
   tab_data[, c("wml", "fp_par_xml", "run_openxml") := list(
     paste0("<w:p>", .SD$fp_par_xml, .SD$run_openxml, "</w:p>"),
@@ -248,7 +259,7 @@ wml_rows <- function(value, split = FALSE) {
   tab_data[tab_data$rowspan < 1, c("wml") := list("")]
 
   cells <- dcast(
-    data = tab_data, formula = .part + ft_row_id ~ col_id,
+    data = tab_data, formula = .part + .row_id ~ .col_id,
     drop = TRUE, fill = "", value.var = "wml",
     fun.aggregate = I
   )
