@@ -31,10 +31,12 @@ htmltools_value <- function(x, ft.align = NULL, ft.shadow = NULL,
   list_deps <- html_dependencies_list(x)
 
   html_o <- tagList(
-    if (length(extra_dependencies) > 0) attachDependencies(
-      x = tags$style(""),
-      extra_dependencies
-    ),
+    if (length(extra_dependencies) > 0) {
+      attachDependencies(
+        x = tags$style(""),
+        extra_dependencies
+      )
+    },
     attachDependencies(
       x = tags$style(""),
       list_deps
@@ -48,11 +50,14 @@ htmltools_value <- function(x, ft.align = NULL, ft.shadow = NULL,
   html_o
 }
 
+#' @importFrom knitr knit_child
 #' @export
-#' @title flextable raw code
+#' @title Knitr rendering in loops and if statements
 #'
-#' @description Print openxml, latex or html code of a
-#' flextable. The function is particularly useful when you want
+#' @description Print flextable in R Markdown or Quarto documents
+#' within `for` loop or `if` statement.
+#'
+#' The function is particularly useful when you want
 #' to generate flextable in a loop from a R Markdown document.
 #'
 #' Inside R Markdown document, chunk option `results` must be
@@ -83,49 +88,24 @@ htmltools_value <- function(x, ft.align = NULL, ft.shadow = NULL,
 flextable_to_rmd <- function(x, ...) {
   is_bookdown <- is_in_bookdown()
   is_quarto <- is_in_quarto()
-  x <- knitr_update_properties(x)
 
-  if (is.null(pandoc_to())) {
-    # for 'glossr' test
-    return(invisible("```{=html}\n<div class=\"tabwid tabwid_left\"><style></style></div>\n```\n"))
-  } else if (is_html_output()) { # html
-    type_output <- "html"
-  } else if (is_latex_output()) { # latex
-    type_output <- "pdf"
-  } else if (grepl("docx", opts_knit$get("rmarkdown.pandoc.to"))) { # docx
-    type_output <- "docx"
-  } else if (grepl("pptx", opts_knit$get("rmarkdown.pandoc.to"))) { # pptx
-    type_output <- "pptx"
+  x <- knitr_update_properties(x, bookdown = is_bookdown, quarto = is_quarto)
+
+  if (is_quarto) {
+    tmp_file <- tempfile(fileext = ".Rmd")
   } else {
-    type_output <- "html"
+    tmp_file <- tempfile(fileext = ".qmd")
   }
 
-  if ("html" %in% type_output) {
-    x <- flextable_global$defaults$post_process_all(x)
-    x <- flextable_global$defaults$post_process_html(x)
-    if (!is_bookdown) {
-      caption <- caption_default_html(x)
-      manual_css <- attr(caption, "css")
-    } else {
-      caption <- caption_bookdown_html(x)
-      manual_css <- ""
-    }
-    str <- gen_raw_html(x,
-      class = "tabwid",
-      caption = caption,
-      manual_css = manual_css
-    )
-    str <- raw_block(str, type = "html")
-  } else if ("docx" %in% type_output) {
-    str <- knit_to_wml(x, bookdown = is_bookdown, quarto = is_quarto)
-  } else if ("pptx" %in% type_output) {
-    str <- knit_to_pml(x)
-  } else if ("pdf" %in% type_output) {
-    str <- knit_to_latex(x, bookdown = is_bookdown, quarto = is_quarto)
-    add_latex_dep()
-    str <- raw_latex(x = str)
-  }
-  cat(str)
+  writeLines(
+    c("```{r echo=FALSE}",
+      "x", "```", ""),
+    tmp_file,
+    useBytes = TRUE)
+
+  z <- knit_child(input = tmp_file, envir = environment(), quiet = TRUE)
+  cat(z, sep = '\n')
+
   invisible("")
 }
 
@@ -164,15 +144,16 @@ to_html.flextable <- function(x, type = c("table", "img"), ...) {
     gr <- gen_grob(x, fit = "fixed", just = "center")
     dims <- dim(gr)
     expand <- 10
-    width <- dims$width + expand/72
-    height <- dims$height + expand/72
+    width <- dims$width + expand / 72
+    height <- dims$height + expand / 72
 
     agg_png(
       filename = tmp,
-      width = dims$width + expand/72,
-      height = dims$height + expand/72,
+      width = dims$width + expand / 72,
+      height = dims$height + expand / 72,
       res = 200, units = "in",
-      background = "transparent")
+      background = "transparent"
+    )
 
     tryCatch(
       {
@@ -605,7 +586,8 @@ print.flextable <- function(x, preview = "html", align = "center", ...) {
 #'
 #' Some features are not implemented in PDF due to technical
 #' infeasibility. These are the padding, line_spacing and
-#' height properties.
+#' height properties. Note also justified text is not supported
+#' and is transformed to left.
 #'
 #' It is recommended to set theses values in a
 #' 'knitr r chunk' so that they are permanent
@@ -662,10 +644,10 @@ knit_print.flextable <- function(x, ...) {
   if (is.null(pandoc_to())) {
     str <- to_html(x, type = "table")
     str <- asis_output(str)
-  } else if (!is.null(getOption("xaringan.page_number.offset"))) { #xaringan
+  } else if (!is.null(getOption("xaringan.page_number.offset"))) { # xaringan
     str <- knit_to_html(x, bookdown = FALSE, quarto = FALSE)
     str <- asis_output(str, meta = html_dependencies_list(x))
-  } else if (is_html_output(excludes="gfm")) { # html
+  } else if (is_html_output(excludes = "gfm")) { # html
     str <- knit_to_html(x, bookdown = is_bookdown, quarto = is_quarto)
     str <- raw_html(str, meta = html_dependencies_list(x))
   } else if (is_latex_output()) { # latex
@@ -748,14 +730,16 @@ save_as_html <- function(..., values = NULL, path,
   show_names <- !is.null(titles)
   if (show_names) {
     old_values <- values
-    values <- rep(list(NULL), length(old_values)*2)
-    values[seq_along(old_values)*2] <- old_values
-    values[seq_along(old_values)*2 - 1] <- lapply(titles, htmltools::h2)
+    values <- rep(list(NULL), length(old_values) * 2)
+    values[seq_along(old_values) * 2] <- old_values
+    values[seq_along(old_values) * 2 - 1] <- lapply(titles, htmltools::h2)
   }
   values <- do.call(htmltools::tagList, values)
 
-  is_succes <- render_htmltag(x = values, path = absolute_path(path), title = title,
-                              lang = lang)
+  is_succes <- render_htmltag(
+    x = values, path = absolute_path(path), title = title,
+    lang = lang
+  )
   if (!is_succes) stop("could not write the file ", shQuote(path))
   invisible(path)
 }
@@ -918,7 +902,8 @@ save_as_docx <- function(..., values = NULL, path, pr_section = NULL, align = "c
 #'   page_margins = page_mar(),
 #'   header_default = block_list(
 #'     fpar(ftext("text for default page header")),
-#'       qflextable(data.frame(a = 1L)))
+#'     qflextable(data.frame(a = 1L))
+#'   )
 #' )
 #' tf <- tempfile(fileext = ".rtf")
 #' save_as_rtf(
@@ -952,11 +937,12 @@ save_as_rtf <- function(..., values = NULL, path, pr_section = NULL) {
   for (i in seq_along(values)) {
     if (show_names) {
       z <- rtf_add(z,
-                   value = fpar(
-                     titles[i],
-                     fp_p = fp_par(text.align = "left", padding.top = 6, padding.bottom = 6),
-                     fp_t = fp_text_lite(bold = TRUE, font.size = 18, font.family = "Arial")
-                   ))
+        value = fpar(
+          titles[i],
+          fp_p = fp_par(text.align = "left", padding.top = 6, padding.bottom = 6),
+          fp_t = fp_text_lite(bold = TRUE, font.size = 18, font.family = "Arial")
+        )
+      )
     }
     z <- rtf_add(z, values[[i]])
   }
@@ -967,10 +953,20 @@ save_as_rtf <- function(..., values = NULL, path, pr_section = NULL) {
 
 
 #' @export
-#' @title Save a flextable in an 'png' file
-#' @description Save a flextable as a png image.
+#' @title Save a flextable in a 'png' or 'svg' file
+#' @description Save a flextable as a png or svg image.
+#' This function uses R graphic system to create an image from the flextable,
+#' allowing for high-quality image output. See [gen_grob()] for more options.
+#'
+#' @section caption:
+#' It's important to note that captions are not part of the table itself.
+#' This means when exporting a table to PNG or SVG formats (image formats),
+#' the caption won't be included. Captions are intended for document outputs
+#' like Word, HTML, or PDF, where tables are embedded within the document
+#' itself.
 #' @param x a flextable object
-#' @param path image file to be created. It should end with '.png'.
+#' @param path image file to be created. It should end with '.png'
+#' or '.svg'.
 #' @param expand space in pixels to add around the table.
 #' @param res The resolution of the device
 #' @param ... unused arguments
@@ -993,15 +989,36 @@ save_as_image <- function(x, path, expand = 10, res = 200, ...) {
     stop(sprintf("Function `%s` supports only flextable objects.", as.character(sys.call()[[1]])))
   }
 
+  file_ext_pos <- regexpr("\\.([[:alnum:]]+)$", path)
+  file_ext <- substring(path, file_ext_pos + 1L)
+
+  file_ext <- match.arg(tolower(file_ext), choices = c("png", "svg"), several.ok = FALSE)
+
   gr <- gen_grob(x, fit = "fixed", just = "center")
   dims <- dim(gr)
 
-  agg_png(
-    filename = path,
-    width = dims$width + expand/72,
-    height = dims$height + expand/72,
-    res = res, units = "in",
-    background = "transparent")
+  if (file_ext %in% "png") {
+    agg_png(
+      filename = path,
+      width = dims$width + expand / 72,
+      height = dims$height + expand / 72,
+      res = res, units = "in",
+      background = "transparent"
+    )
+  } else if (file_ext %in% "svg") {
+    if (!requireNamespace("svglite", quietly = TRUE)) {
+      stop(sprintf(
+        "'%s' package should be installed to save a flextable in a '%s' image.",
+        "svglite"
+      ))
+    }
+    svglite::svglite(
+      filename = path,
+      width = dims$width + expand / 72,
+      height = dims$height + expand / 72,
+      bg = "transparent"
+    )
+  }
 
   tryCatch(
     {
@@ -1024,6 +1041,7 @@ save_as_image <- function(x, path, expand = 10, res = 200, ...) {
 #' should be used to ensure a correct rendering.
 #' @param x a flextable object
 #' @param ... additional arguments passed to [gen_grob()].
+#' @inheritSection save_as_image caption
 #' @examples
 #' library(gdtools)
 #' library(ragg)
@@ -1032,8 +1050,10 @@ save_as_image <- function(x, path, expand = 10, res = 200, ...) {
 #' ftab <- as_flextable(cars)
 #'
 #' tf <- tempfile(fileext = ".png")
-#' agg_png(filename = tf, width = 1.7, height = 3.26, unit = "in",
-#'   background = "transparent", res = 150)
+#' agg_png(
+#'   filename = tf, width = 1.7, height = 3.26, unit = "in",
+#'   background = "transparent", res = 150
+#' )
 #' plot(ftab)
 #' dev.off()
 #' @family flextable print function
@@ -1073,6 +1093,7 @@ plot.flextable <- function(x, ...) {
 #' @family flextable print function
 #' @keywords internal
 as_raster <- function(x, ...) {
+  .Deprecated(new = "gen_grob()")
   if (!requireNamespace("magick", quietly = TRUE)) {
     stop(sprintf(
       "'%s' package should be installed to create an image from a flextable.",
@@ -1096,7 +1117,18 @@ is_in_bookdown <- function() {
     isTRUE(!is_rdocx_document)
 }
 is_in_quarto <- function() {
-  isTRUE(knitr::opts_knit$get("quarto.version") > numeric_version("0"))
+  if (getRversion() >= numeric_version("4.4.0")) {
+    isTRUE(knitr::opts_knit$get("quarto.version") > 0)
+  } else {
+    isTRUE(knitr::opts_knit$get("quarto.version") > numeric_version("0"))
+  }
+}
+fake_quarto <- function() {
+  if (getRversion() >= numeric_version("4.4.0")) {
+    knitr::opts_knit$set("quarto.version" = 1)
+  } else {
+    knitr::opts_knit$set("quarto.version" = numeric_version("1.0"))
+  }
 }
 is_in_pkgdown <- function() {
   identical(Sys.getenv("IN_PKGDOWN"), "true") &&
@@ -1105,7 +1137,6 @@ is_in_pkgdown <- function() {
 
 #' @importFrom knitr opts_current
 knitr_update_properties <- function(x, bookdown = FALSE, quarto = FALSE) {
-
   # global properties
   ft.align <- opts_current$get("ft.align")
   ft.split <- opts_current$get("ft.split")
@@ -1138,17 +1169,18 @@ knitr_update_properties <- function(x, bookdown = FALSE, quarto = FALSE) {
   }
 
   # captions properties
-  knitr_tab_opts = opts_current_table()
+  knitr_tab_opts <- opts_current_table()
   if (is.null(knitr_tab_opts$cap.style)) {
     knitr_tab_opts$cap.style <- "Table Caption"
   }
   x <- update_caption(
     x = x,
     caption = knitr_tab_opts$cap,
-    word_stylename = knitr_tab_opts$cap.style)
+    word_stylename = knitr_tab_opts$cap.style
+  )
   if (has_caption(x) &&
-      !has_autonum(x) &&
-      !is.null(knitr_tab_opts$id)) {
+    !has_autonum(x) &&
+    !is.null(knitr_tab_opts$id)) {
     autonum <- run_autonum(
       seq_id = gsub(":$", "", knitr_tab_opts$tab.lp),
       pre_label = knitr_tab_opts$cap.pre,
@@ -1163,4 +1195,3 @@ knitr_update_properties <- function(x, bookdown = FALSE, quarto = FALSE) {
 
   x
 }
-
